Mikä OiRA on? | OiRA

Aiheet

# Mikä OiRA on?

## Käytätkö OiRA-järjestelmää ensimmäistä kertaa?

Tässä on lyhyt johdanto riskinarviointiin sekä siihen, miten OiRA voi auttaa riskien hallinnassa.

## Mitä riskinarviointi on?

Riskinarviointi on turvallisuuden ja terveyden menestyksekkään edistämisen perusta sekä avain työtapaturmien ja työperäisten sairauksien vähentämiseen. Jos se toteutetaan hyvin, se voi parantaa työterveyttä ja -turvallisuutta - ja yleisesti yrityksen tulosta.

Työntekijöiden turvallisuutta ja terveyttä suojellaan Euroopassa arvioimalla ja hallitsemalla riskitekijöitä työpaikalla. Työnantajilla on lakisääteinen velvollisuus varmistaa työterveys ja -turvallisuus kaikissa työhön liittyvissä näkökohdissa ja tehdä arviointi työhön liittyvistä riskeistä. Kaikkien yritysten on siis tehtävä riskinarviointi ja laadittava siihen liittyvä toimintasuunnitelma. Tehokkaan riskinarvioinnin tekeminen työpaikalla edellyttää, että kaikki asianosaiset tuntevat

- sen oikeudellisen taustan ja oikeudelliset käsitteet
- riskien arviointiin käytettävän menettelyn
- menettelyssä mukana olevien keskeisten toimijoiden tehtävät.

Työntekijöillä ja/tai heidän edustajillaan on oikeus tulla kuulluksi järjestelyistä, jotka koskevat riskinarvioinnin tekemistä ja siihen osallistumista.

OiRA-hankkeen verkkosivustolla on lisätietoa riskinarvioinnista ja työntekijöiden ja/tai heidän edustajiensa osallistumisesta riskinarviointimenettelyyn.

## Mikä OiRA on?

OiRA tarkoittaa vuorovaikutteista riskinarvioinnin verkkotyökalua (Online Interactive Risk Assessment). Se on verkkosovellus, jonka avulla työpaikan terveys- ja turvallisuusriskit voidaan arvioida.

## Kenelle OiRA on tarkoitettu?

OiRAa voi käyttää kuka tahansa, joka arvioi terveyteen tai turvallisuuteen liittyviä riskejä, joita omalla työpaikalla voi esiintyä.

OiRA on kuitenkin suunniteltu erityisesti pienille yrityksille. OiRA on kehitetty erityisesti tukemaan niitä työpaikan riskien arvioinnissa ja auttamaan niitä dokumentoidun riskinarvioinnin sekä yrityksen vaatimuksiin soveltuvan toimintasuunnitelman laatimisessa.

## Miten arviointi tehdään?

OiRAn riskinarviointimenettelyssä on useita vaiheita:

- Suunnittelu: Joissakin työkaluissa on profiiliin liittyviä kysymyksiä, joiden avulla työkalua muokataan vastaamaan yrityksesi ominaisuuksia. Kun vastaat profiilikysymyksiin, työkalu mukautuu yrityksesi tilanteeseen ja näyttää soveltuvat moduulit.

- Osallistuminen: Työntekijöiden on osallistuttava aktiivisesti kaikkiin riskinarviointeihin. Voit tulostaa työkalusta koko riskinarvioinnin tekstin tai sen osia, jotta voit antaa työntekijöille tietoa ja saada heiltä palautetta.

- Riskien tunnistaminen: OiRA esittää sarjan mahdollisia terveyteen ja turvallisuuteen liittyviä vaaroja tai ongelmia, joita työpaikallasi voi ilmetä. Vastaamalla väittämiin/kysymyksiin ”kyllä” tai ”ei” ilmoitat, onko kyseisiä vaaroja tai ongelmia olemassa. Voit myös jättää vastaamatta kysymykseen ja palata siihen myöhemmin.

- Arviointi: Joissakin työkaluissa pyydetään asettamaan määritetyt riskit tärkeysjärjestykseen. Riskien järjestämistapa määräytyy sen perusteella, mitä kansalliset OiRA-kumppanit / OiRA-työkalun kehittäjät ovat päättäneet ja mikä on heidän nimenomainen lähestymistapansa tärkeysjärjestyksen määrittämiseen. Jotkin työkalut myös panevat riskit automaattisesti järjestykseen taustalla. Tätä järjestystä voi muuttaa.

- Toimintasuunnitelma: Työkalu pyytää valitsemaan kunkin tunnistetun riskin osalta yhden tai useamman toimenpiteen, jolla kyseistä riskiä lievennetään tai jolla se voidaan poistaa. Useimmat työkalut ehdottavat joitakin toimenpiteitä. Voit myös lisätä itse määrittämiäsi toimenpiteitä.

- Raportti: Lainsäädäntö edellyttää riskinarvioinnin dokumentoimista. Raporttiosiossa on useita erilaisia raportteja, jotka auttavat seuraamaan riskinarvioinnin tilaa ja toteuttamaan jatkotoimia/-toimenpiteitä, jotka on päätetty tehdä tunnistettujen riskien poistamiseksi tai niiden lieventämiseksi.

## Miten kauan arvioinnin tekeminen kestää?

Arvioinnin tekemisen kestoa ei voi sanoa tarkasti, koska työkalut ovat erilaisia eri toimialoilla ja eri maissa.

Voit kuitenkin käyttää arviointiin käytössäsi olevan ajan ja palata siihen, kun sinulle sopii, ja jatkaa samasta kohdasta, mihin jäit.

## Miksi rekisteröinti on tarpeen?

Ennen ensimmäisen riskinarvioinnin aloittamista sinua pyydetään luomaan OiRA-tili - se käy helposti ja nopeasti.

Kun olet rekisteröitynyt, voit kirjautua järjestelmään milloin tahansa, jatkaa edellisten arviointien tekemistä tai aloittaa uusia.

Jos olet rekisteröitynyt käyttäjä, voit myös milloin tahansa tulostaa tarkan ja ajantasaisen riskinarvioinnin.

## Tarvitaanko valmisteluja?

Työkalun käytön aloittaminen ei edellytä mitään erityisiä valmisteluja. Kannattaa kuitenkin pohtia hetki, kuka tekee riskinarvioinnin ja miten työntekijät saadaan osallistumaan menettelyyn.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More